=======================
Developer documentation
=======================

Reading and writing code
------------------------

..  container:: two-column 

    ..  toctree::
        :maxdepth: 2
        :numbered:

        codebase/index
        coding_standards/index
        documentation/index
        tests/index


Developer tools
---------------

..  container:: two-column 

    ..  toctree::
        :maxdepth: 2
        :numbered:

        ajv/index
        ajv_book/index


Development notes
-----------------

..  toctree::
    :maxdepth: 2
    :numbered:

    timing/index
    profiling/index
    memory/index
    class_attributes/index
    slots/index
